@@ -18,14 +18,10 @@
 #
 # Written by Neil Bowers <neil@bowers.com>
 #
-# Copyright (C) 2002 Neil Bowers.
+# Copyright (C) 2002-2013 Neil Bowers.
 # Copyright (C) 1998-2001 Canon Research Centre Europe Ltd.
 # All Rights Reserved.
 #
-#-----------------------------------------------------------------------
-#
-# $Id: Std.pm,v 1.6 2002/03/06 08:24:34 neilb Exp $
-#
 #=======================================================================
 
 package AppConfig::Std;
@@ -36,7 +32,7 @@ use AppConfig;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.08';
 @ISA     = qw(AppConfig);
 
 #=======================================================================
@@ -73,6 +69,7 @@ sub new
     return $self;
 }
 
+
 #=======================================================================
 #
 # args() - parse command-line arguments (@ARGV)
@@ -97,35 +94,87 @@ sub args
     #-------------------------------------------------------------------
     # If the command-line was successfully parsed (returned TRUE),
     # then check for the standard command-line switches.
-    # We only load Pod::Usage if we're gonna use it.
-    # Because we're require'ing, the functions don't get exported
-    # to us, hence the explicit namespace reference.
     #-------------------------------------------------------------------
     if ($result)
     {
-        require Pod::Usage if $self->doc || $self->help;
-        Pod::Usage::pod2usage({-verbose => 2, -exitval => 0}) if $self->doc();
-        Pod::Usage::pod2usage({-verbose => 1, -exitval => 0}) if $self->help();
-        show_version() if $self->version();
+	$self->_handle_std_opts();
     }
 
     return $result;
 }
 
+
 #=======================================================================
 #
-# show_version()
+# getopt() - parse command-line arguments (@ARGV)
+#
+# We over-ride the getopt() method, to handle the -doc, -help
+# and -version command-line switches.
+#
+#=======================================================================
+sub getopt
+{
+    my $self = shift;
+    my $ref  = shift;
+
+    my $result;
+
+
+    #-------------------------------------------------------------------
+    # Use AppConfig's getopt() method to parse the command-line.
+    #-------------------------------------------------------------------
+    $result = $self->SUPER::getopt($ref);
+
+    #-------------------------------------------------------------------
+    # If the command-line was successfully parsed (returned TRUE),
+    # then check for the standard command-line switches.
+    #-------------------------------------------------------------------
+    if ($result)
+    {
+	$self->_handle_std_opts();
+    }
+
+    return $result;
+}
+
+
+#=======================================================================
+#
+# _handle_std_opts() - handle the standard options defined by us
+#
+#=======================================================================
+sub _handle_std_opts
+{
+    my $self = shift;
+
+
+    #-------------------------------------------------------------------
+    # We only load Pod::Usage if we're gonna use it.
+    # Because we're require'ing, the functions don't get exported
+    # to us, hence the explicit namespace reference.
+    #-------------------------------------------------------------------
+    require Pod::Usage if $self->doc || $self->help;
+    Pod::Usage::pod2usage({-verbose => 2, -exitval => 0}) if $self->doc();
+    Pod::Usage::pod2usage({-verbose => 1, -exitval => 0}) if $self->help();
+    _show_version() if $self->version();
+}
+
+
+#=======================================================================
+#
+# _show_version()
 #
 # Display the version number of the script. This assumes that
 # the invoking script has defined $VERSION.
 #
 #=======================================================================
-sub show_version
+sub _show_version
 {
     print "$main::VERSION\n";
     exit 0;
 }
 
+
 1;
 
 __END__
@@ -207,7 +256,7 @@ This assumes that you have defined C<$VERSION> in your script
 with something like the following:
 
     use vars qw( $VERSION );
-    $VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+    $VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 The script will exit with an exit value of 0.
 
@@ -309,13 +358,17 @@ AppConfig::Std uses Pod::Usage, which assumes well-formed pod.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/AppConfig-Std>
+
 =head1 AUTHOR
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 Neil Bowers.
+Copyright (c) 2002-2013 Neil Bowers.
 
 Copyright (c) 1998-2001 Canon Research Centre Europe. All rights reserved.
 
